Class: Aws::ManagedBlockchainQuery::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ManagedBlockchainQuery::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-managedblockchainquery/client.rb,
sig/client.rbs
Overview
An API client for ManagedBlockchainQuery. To construct a client, you need to configure a :region and :credentials.
client = Aws::ManagedBlockchainQuery::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetTokenBalanceResponseSuccess, _GetAssetContractResponseSuccess, _GetTokenBalanceResponseSuccess, _GetTransactionResponseSuccess, _ListAssetContractsResponseSuccess, _ListFilteredTransactionEventsResponseSuccess, _ListTokenBalancesResponseSuccess, _ListTransactionEventsResponseSuccess, _ListTransactionsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_token_balance(params = {}) ⇒ Types::BatchGetTokenBalanceOutput
Gets the token balance for a batch of tokens by using the
BatchGetTokenBalanceaction for every token in the request. -
#get_asset_contract(params = {}) ⇒ Types::GetAssetContractOutput
Gets the information about a specific contract deployed on the blockchain.
-
#get_token_balance(params = {}) ⇒ Types::GetTokenBalanceOutput
Gets the balance of a specific token, including native tokens, for a given address (wallet or contract) on the blockchain.
-
#get_transaction(params = {}) ⇒ Types::GetTransactionOutput
Gets the details of a transaction.
-
#list_asset_contracts(params = {}) ⇒ Types::ListAssetContractsOutput
Lists all the contracts for a given contract type deployed by an address (either a contract address or a wallet address).
-
#list_filtered_transaction_events(params = {}) ⇒ Types::ListFilteredTransactionEventsOutput
Lists all the transaction events for an address on the blockchain.
-
#list_token_balances(params = {}) ⇒ Types::ListTokenBalancesOutput
This action returns the following for a given blockchain network:.
-
#list_transaction_events(params = {}) ⇒ Types::ListTransactionEventsOutput
Lists all the transaction events for a transaction.
-
#list_transactions(params = {}) ⇒ Types::ListTransactionsOutput
Lists all the transaction events for a transaction.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1216 1217 1218 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 1216 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1219 1220 1221 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 1219 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_get_token_balance(params = {}) ⇒ Types::BatchGetTokenBalanceOutput
Gets the token balance for a batch of tokens by using the
BatchGetTokenBalance action for every token in the request.
87 |
# File 'sig/client.rbs', line 87
def batch_get_token_balance: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 1189 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ManagedBlockchainQuery') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-managedblockchainquery' context[:gem_version] = '1.46.0' Seahorse::Client::Request.new(handlers, context) end |
#get_asset_contract(params = {}) ⇒ Types::GetAssetContractOutput
Gets the information about a specific contract deployed on the blockchain.
- Metadata is currently only available for some
ERC-20contracts. Metadata will be available for additional contracts in the future.
114 |
# File 'sig/client.rbs', line 114
def get_asset_contract: (
|
#get_token_balance(params = {}) ⇒ Types::GetTokenBalanceOutput
Gets the balance of a specific token, including native tokens, for a given address (wallet or contract) on the blockchain.
131 |
# File 'sig/client.rbs', line 131
def get_token_balance: (
|
#get_transaction(params = {}) ⇒ Types::GetTransactionOutput
Gets the details of a transaction.
151 |
# File 'sig/client.rbs', line 151
def get_transaction: (
|
#list_asset_contracts(params = {}) ⇒ Types::ListAssetContractsOutput
Lists all the contracts for a given contract type deployed by an address (either a contract address or a wallet address).
The Bitcoin blockchain networks do not support this operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
164 |
# File 'sig/client.rbs', line 164
def list_asset_contracts: (
|
#list_filtered_transaction_events(params = {}) ⇒ Types::ListFilteredTransactionEventsOutput
Lists all the transaction events for an address on the blockchain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
181 |
# File 'sig/client.rbs', line 181
def list_filtered_transaction_events: (
|
#list_token_balances(params = {}) ⇒ Types::ListTokenBalancesOutput
This action returns the following for a given blockchain network:
-
Lists all token balances owned by an address (either a contract address or a wallet address).
-
Lists all token balances for all tokens created by a contract.
-
Lists all token balances for a given token.
tokenFilter when
using this operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
215 |
# File 'sig/client.rbs', line 215
def list_token_balances: (
|
#list_transaction_events(params = {}) ⇒ Types::ListTransactionEventsOutput
Lists all the transaction events for a transaction
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
235 |
# File 'sig/client.rbs', line 235
def list_transaction_events: (
|
#list_transactions(params = {}) ⇒ Types::ListTransactionsOutput
Lists all the transaction events for a transaction.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
250 |
# File 'sig/client.rbs', line 250
def list_transactions: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1209 1210 1211 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 1209 def waiter_names [] end |