Class: Aws::ManagedBlockchainQuery::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ManagedBlockchainQuery::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-managedblockchainquery/client.rb
Overview
An API client for ManagedBlockchainQuery. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ManagedBlockchainQuery::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_token_balance(params = {}) ⇒ Types::BatchGetTokenBalanceOutput
Gets the token balance for a batch of tokens by using the ‘BatchGetTokenBalance` action for every token in the request.
-
#get_asset_contract(params = {}) ⇒ Types::GetAssetContractOutput
Gets the information about a specific contract deployed on the blockchain.
-
#get_token_balance(params = {}) ⇒ Types::GetTokenBalanceOutput
Gets the balance of a specific token, including native tokens, for a given address (wallet or contract) on the blockchain.
-
#get_transaction(params = {}) ⇒ Types::GetTransactionOutput
Gets the details of a transaction.
-
#list_asset_contracts(params = {}) ⇒ Types::ListAssetContractsOutput
Lists all the contracts for a given contract type deployed by an address (either a contract address or a wallet address).
-
#list_filtered_transaction_events(params = {}) ⇒ Types::ListFilteredTransactionEventsOutput
Lists all the transaction events for an address on the blockchain.
-
#list_token_balances(params = {}) ⇒ Types::ListTokenBalancesOutput
This action returns the following for a given blockchain network:.
-
#list_transaction_events(params = {}) ⇒ Types::ListTransactionEventsOutput
Lists all the transaction events for a transaction.
-
#list_transactions(params = {}) ⇒ Types::ListTransactionsOutput
Lists all the transaction events for a transaction.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1216 1217 1218 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 1216 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1219 1220 1221 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 1219 def errors_module Errors end |
Instance Method Details
#batch_get_token_balance(params = {}) ⇒ Types::BatchGetTokenBalanceOutput
Gets the token balance for a batch of tokens by using the ‘BatchGetTokenBalance` action for every token in the request.
<note markdown=“1”> Only the native tokens BTC and ETH, and the ERC-20, ERC-721, and ERC 1155 token standards are supported.
</note>
538 539 540 541 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 538 def batch_get_token_balance(params = {}, = {}) req = build_request(:batch_get_token_balance, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 1189 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ManagedBlockchainQuery') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-managedblockchainquery' context[:gem_version] = '1.44.0' Seahorse::Client::Request.new(handlers, context) end |
#get_asset_contract(params = {}) ⇒ Types::GetAssetContractOutput
Gets the information about a specific contract deployed on the blockchain.
<note markdown=“1”> * The Bitcoin blockchain networks do not support this operation.
-
Metadata is currently only available for some ‘ERC-20` contracts. Metadata will be available for additional contracts in the future.
</note>
587 588 589 590 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 587 def get_asset_contract(params = {}, = {}) req = build_request(:get_asset_contract, params) req.send_request() end |
#get_token_balance(params = {}) ⇒ Types::GetTokenBalanceOutput
Gets the balance of a specific token, including native tokens, for a given address (wallet or contract) on the blockchain.
<note markdown=“1”> Only the native tokens BTC and ETH, and the ERC-20, ERC-721, and ERC 1155 token standards are supported.
</note>
653 654 655 656 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 653 def get_token_balance(params = {}, = {}) req = build_request(:get_token_balance, params) req.send_request() end |
#get_transaction(params = {}) ⇒ Types::GetTransactionOutput
Gets the details of a transaction.
<note markdown=“1”> This action will return transaction details for all transactions that are confirmed on the blockchain, even if they have not reached [finality].
</note>
[1]: docs.aws.amazon.com/managed-blockchain/latest/ambq-dg/key-concepts.html#finality
724 725 726 727 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 724 def get_transaction(params = {}, = {}) req = build_request(:get_transaction, params) req.send_request() end |
#list_asset_contracts(params = {}) ⇒ Types::ListAssetContractsOutput
Lists all the contracts for a given contract type deployed by an address (either a contract address or a wallet address).
The Bitcoin blockchain networks do not support this operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
787 788 789 790 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 787 def list_asset_contracts(params = {}, = {}) req = build_request(:list_asset_contracts, params) req.send_request() end |
#list_filtered_transaction_events(params = {}) ⇒ Types::ListFilteredTransactionEventsOutput
Lists all the transaction events for an address on the blockchain.
<note markdown=“1”> This operation is only supported on the Bitcoin networks.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
905 906 907 908 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 905 def list_filtered_transaction_events(params = {}, = {}) req = build_request(:list_filtered_transaction_events, params) req.send_request() end |
#list_token_balances(params = {}) ⇒ Types::ListTokenBalancesOutput
This action returns the following for a given blockchain network:
-
Lists all token balances owned by an address (either a contract address or a wallet address).
-
Lists all token balances for all tokens created by a contract.
-
Lists all token balances for a given token.
<note markdown=“1”> You must always specify the network property of the ‘tokenFilter` when using this operation.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
995 996 997 998 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 995 def list_token_balances(params = {}, = {}) req = build_request(:list_token_balances, params) req.send_request() end |
#list_transaction_events(params = {}) ⇒ Types::ListTransactionEventsOutput
Lists all the transaction events for a transaction
<note markdown=“1”> This action will return transaction details for all transactions that are confirmed on the blockchain, even if they have not reached [finality].
</note>
[1]: docs.aws.amazon.com/managed-blockchain/latest/ambq-dg/key-concepts.html#finality
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1087 1088 1089 1090 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 1087 def list_transaction_events(params = {}, = {}) req = build_request(:list_transaction_events, params) req.send_request() end |
#list_transactions(params = {}) ⇒ Types::ListTransactionsOutput
Lists all the transaction events for a transaction.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1180 1181 1182 1183 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 1180 def list_transactions(params = {}, = {}) req = build_request(:list_transactions, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1209 1210 1211 |
# File 'lib/aws-sdk-managedblockchainquery/client.rb', line 1209 def waiter_names [] end |